@@ -181,7 +181,7 @@ net_workarea_changed (FMDesktopIconView *icon_view,
 			       &format_returned,
 			       &length_returned,
 			       (guchar **) &nworkareas)) {
-		g_warning("Can not caclulate _NET_NUMBER_OF_DESKTOPS");
+		g_warning("Can not calculate _NET_NUMBER_OF_DESKTOPS");
 	}
 	if (gdk_error_trap_pop()
 	    || nworkareas == NULL
@@ -615,8 +615,8 @@ action_change_background_callback (GtkAction *action,
 
 	nautilus_launch_application_from_command (gtk_widget_get_screen (GTK_WIDGET (data)),
 						  _("Background"),
-						  "gnome-background-properties",
-						  NULL,
+						  "gnome-appearance-properties",
+						  "--show-page=background",
 						  FALSE);
 }
 
