@@ -31,7 +31,7 @@
 
 void     nautilus_main_event_loop_register    (GtkObject *object);
 gboolean nautilus_main_is_event_loop_mainstay (GtkObject *object);
-void     nautilus_main_event_loop_quit        (void);
+void     nautilus_main_event_loop_quit        (gboolean explicit);
 
 #endif /* NAUTILUS_MAIN_H */
 
